==> jena-3.17.0-source-release.zip: jena-3.17.0/jena-arq/src/main/java/org/apache/jena/sparql/engine/QueryIterator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.engine;

import java.util.Iterator ;

import org.apache.jena.atlas.lib.Closeable ;
import org.apache.jena.sparql.engine.binding.Binding ;
import org.apache.jena.sparql.util.PrintSerializable ;

/** Root of query iterators in ARQ. */

public interface QueryIterator extends Closeable, Iterator<Binding>, PrintSerializable
{
    /** Get next binding */ 
    public Binding nextBinding() ;
    
    /**
     * Cancels the query as soon as is possible for the given iterator
     */
    public void cancel();
    
    /*
     * Indicate whether this iterator is known to be an iterator of the join identity (one row, no columns).
     * Returns true if definitely a join identity; false for not or don't know.
     */
    public default boolean isJoinIdentity() { return false; }
}

==> jena-5.6.0-source-release.zip: jena-5.6.0/jena-arq/src/main/java/org/apache/jena/sparql/engine/QueryIterator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.engine;

import org.apache.jena.atlas.iterator.IteratorCloseable;
import org.apache.jena.sparql.engine.binding.Binding ;
import org.apache.jena.sparql.util.PrintSerializable ;

/** Root of query iterators in ARQ. */

public interface QueryIterator extends IteratorCloseable<Binding>, PrintSerializable
{
    /** Get next binding */
    public Binding nextBinding() ;

    /**
     * Cancels the query as soon as is possible for the given iterator
     */
    public void cancel();

    /*
     * Indicate whether this iterator is known to be an iterator of the join identity (one row, no columns).
     * Returns true if definitely a join identity; false for not or don't know.
     */
    public default boolean isJoinIdentity() { return false; }
}
